"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const DocumentLinksProvider_1 = require("./DocumentLinksProvider");
const documents_1 = require("../documents");
const vscode_uri_1 = require("vscode-uri");
(0, vitest_1.describe)('DocumentLinksProvider', () => {
    let documentManager;
    let documentLinksProvider;
    (0, vitest_1.beforeEach)(() => {
        documentManager = new documents_1.DocumentManager();
        documentLinksProvider = new DocumentLinksProvider_1.DocumentLinksProvider(documentManager);
    });
    (0, vitest_1.it)('should return an empty array for non-LiquidHtml documents', async () => {
        const uriString = 'file:///path/to/non-liquid-html-document.txt';
        const rootUri = 'file:///path/to/project';
        documentManager.open(vscode_uri_1.URI.parse(uriString).toString(), 'Sample plain text content', 1);
        const result = documentLinksProvider.documentLinks(uriString, rootUri);
        (0, vitest_1.expect)(result).toEqual([]);
    });
    (0, vitest_1.it)('should return an empty array for non-existent documents', async () => {
        const uriString = 'file:///path/to/non-existent-document.txt';
        const rootUri = 'file:///path/to/project';
        const result = documentLinksProvider.documentLinks(uriString, rootUri);
        (0, vitest_1.expect)(result).toEqual([]);
    });
    (0, vitest_1.it)('should return a list of document links with correct URLs for a LiquidHtml document', async () => {
        const uriString = 'file:///path/to/liquid-html-document.liquid';
        const rootUri = 'file:///path/to/project';
        const liquidHtmlContent = `
      {% render 'snippet1' %}
      {% include 'snippet2' %}
      {% section 'header' %}
      {% echo 'echo.js' | asset_url %}
      {% assign x = 'assign.css' | asset_url %}
      {{ 'asset.js' | asset_url }}
    `;
        documentManager.open(vscode_uri_1.URI.parse(uriString).toString(), liquidHtmlContent, 1);
        const result = documentLinksProvider.documentLinks(uriString, rootUri);
        const expectedUrls = [
            'file:///path/to/project/snippets/snippet1.liquid',
            'file:///path/to/project/snippets/snippet2.liquid',
            'file:///path/to/project/sections/header.liquid',
            'file:///path/to/project/assets/echo.js',
            'file:///path/to/project/assets/assign.css',
            'file:///path/to/project/assets/asset.js',
        ];
        (0, vitest_1.expect)(result.length).toBe(expectedUrls.length);
        for (let i = 0; i < expectedUrls.length; i++) {
            (0, vitest_1.expect)(result[i].target).toBe(expectedUrls[i]);
        }
    });
});
//# sourceMappingURL=DocumentLinksProvider.spec.js.map