"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: LiquidObjectHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [
                {
                    name: 'product',
                    description: 'product description',
                    return_type: [],
                    properties: [
                        {
                            name: 'featured_image',
                            return_type: [{ type: 'image', name: '' }],
                        },
                        {
                            name: 'title',
                            return_type: [{ type: 'string', name: '' }],
                        },
                    ],
                },
                {
                    name: 'all_products',
                    return_type: [{ type: 'array', array_value: 'product' }],
                },
                {
                    name: 'image',
                    description: 'image description',
                    access: {
                        global: false,
                        parents: [],
                        template: [],
                    },
                },
            ],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should return the hover description of the object', async () => {
        const contexts = [
            '{{ pro█duct }}',
            '{{ product█ }}',
            '{% echo product█ %}',
            '{% liquid\n echo product█ %}',
            '{% assign x = product %}{{ x█ }}',
            '{% for x in all_products %}{{ x█ }}{% endfor %}',
            '{% assign x = all_products[0] %}{{ x█ }}',
        ];
        for (const context of contexts) {
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringContaining('product description'));
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringMatching(/##* \w+: `product`/));
        }
    });
    (0, vitest_1.it)('should return nothing if the thing is untyped', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{{ unknown█ }}`, null);
    });
});
//# sourceMappingURL=LiquidObjectHoverProvider.spec.js.map