"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: LiquidTagHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [
                { name: 'if', description: 'if statement description' },
                { name: 'echo', description: 'echo description' },
            ],
        });
    });
    (0, vitest_1.it)('should return the hover description of the correct tag', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{%█ if cond %}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.hover(`{% i█f cond %}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.hover(`{% if█ cond %}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.hover(`{% if cond █%}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.hover(`{% if cond %}{% █ endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.hover(`{% echo█ 'hi' %}`, vitest_1.expect.stringContaining('echo'));
    });
    (0, vitest_1.it)('should not return the tag hover description when hovering over anything else in the tag', async () => {
        await (0, vitest_1.expect)(provider).to.not.hover(`{% if █cond %}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.not.hover(`{% if c█ond %}{% endif %}`, vitest_1.expect.stringContaining('if'));
        await (0, vitest_1.expect)(provider).to.not.hover(`{% if cond %} █ {%  endif %}`, vitest_1.expect.stringContaining('if'));
    });
    (0, vitest_1.it)('should return nothing if there are no docs for that tag', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{% unknown█ %}`, null);
    });
});
//# sourceMappingURL=LiquidTagHoverProvider.spec.js.map