"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mockConnection = void 0;
const vitest_1 = require("vitest");
const node_events_1 = require("node:events");
const server_1 = require("vscode-languageserver/lib/common/server");
const vscode_languageserver_1 = require("vscode-languageserver");
function protocolConnection(requests, notifications) {
    return {
        dispose: vitest_1.vi.fn(),
        end: vitest_1.vi.fn(),
        hasPendingResponse: vitest_1.vi.fn(),
        listen: vitest_1.vi.fn(),
        onClose: vitest_1.vi.fn(),
        onDispose: vitest_1.vi.fn(),
        onError: vitest_1.vi.fn(),
        onProgress: vitest_1.vi.fn(),
        onNotification: vitest_1.vi.fn().mockImplementation((type, handler) => {
            notifications.addListener(type.method, handler);
        }),
        onRequest: vitest_1.vi.fn().mockImplementation((type, handler) => {
            requests.addListener(type.method, handler);
        }),
        onUnhandledNotification: vitest_1.vi.fn(),
        sendNotification: vitest_1.vi.fn().mockReturnValue(Promise.resolve()),
        sendProgress: vitest_1.vi.fn(),
        sendRequest: vitest_1.vi.fn(),
        trace: vitest_1.vi.fn().mockReturnValue(Promise.resolve()),
    };
}
function mockConnection() {
    const watchDog = {
        exit: vitest_1.vi.fn(),
        initialize: vitest_1.vi.fn(),
        shutdownReceived: false,
    };
    const requests = new node_events_1.EventEmitter();
    const notifications = new node_events_1.EventEmitter();
    const spies = protocolConnection(requests, notifications);
    // Create a real "connection" with the fake communication channel
    const connection = (0, server_1.createConnection)(() => spies, watchDog);
    // Create a mock way to trigger notification in our tests
    const triggerNotification = async (...args) => {
        const [type, params] = args;
        const method = typeof type === 'string' ? type : type.method;
        notifications.emit(method, params);
    };
    // Create a mock way to trigger requests in our tests
    const triggerRequest = async (...args) => {
        const [type, params] = args;
        const method = typeof type === 'string' ? type : type.method;
        requests.emit(method, params);
    };
    const mockConnectionMethods = {
        triggerNotification,
        triggerRequest,
        spies,
        setup() {
            triggerRequest(vscode_languageserver_1.InitializeRequest.method, { capabilities: {} });
            triggerNotification(vscode_languageserver_1.InitializedNotification.method);
        },
        openDocument(relativePath, text) {
            triggerNotification(vscode_languageserver_1.DidOpenTextDocumentNotification.type, {
                textDocument: {
                    languageId: 'liquid',
                    uri: `browser:///${relativePath}`,
                    version: 0,
                    text,
                },
            });
        },
        changeDocument(relativePath, text, version) {
            triggerNotification(vscode_languageserver_1.DidChangeTextDocumentNotification.type, {
                textDocument: {
                    uri: `browser:///${relativePath}`,
                    version,
                },
                contentChanges: [
                    {
                        text,
                    },
                ],
            });
        },
        closeDocument(relativePath) {
            triggerNotification(vscode_languageserver_1.DidCloseTextDocumentNotification.type, {
                textDocument: {
                    uri: `browser:///${relativePath}`,
                },
            });
        },
    };
    return Object.assign(connection, mockConnectionMethods);
}
exports.mockConnection = mockConnection;
//# sourceMappingURL=MockConnection.js.map